/* This file was generated by syncqt. */
#ifndef QT_QTWEBENGINE_VERSION_H
#define QT_QTWEBENGINE_VERSION_H

#define QTWEBENGINE_VERSION_STR "5.15.9"

#define QTWEBENGINE_VERSION 0x050F09

#endif // QT_QTWEBENGINE_VERSION_H
